pyxmpp2.stanzaprocessor

Package pyxmpp2 :: Module stanzaprocessor |
[hide private]

# Module stanzaprocessor

Handling of XMPP stanzas.

Normative reference:
  - RFC 6129

Classes | [hide private]
| StanzaProcessor Universal stanza handler/router class.

Functions | [hide private]
stanza_factory(element, stream=None, language=None) Creates Iq, Message or Presence object for XML stanza `element` |

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.stanzaprocessor")`

Function Details | [hide private]

### stanza_factory(element, stream=None, language=None) |
Creates Iq, Message or Presence object for XML stanza `element` Parameters: `element` (`ElementTree.Element`) - the stanza XML element `stream` (streambase.StreamBase) - stream where the stanza was received `language` (`unicode`) - default language for the stanza